@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2006, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2006, 2008, 2009, 2010 Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -19,7 +19,7 @@
 #ifndef HOME_DIR_H
 # define HOME_DIR_H
 
-# include "stdafx.h"
+# include "myserver.h"
 # include <include/base/file/file.h>
 # include <include/base/string/stringutils.h>
 # include <include/base/hash_map/hash_map.h>
@@ -47,7 +47,7 @@ private:
 
 # ifdef WIN32
   string data;
-# elif !GETPWNAM
+# elif !HAVE_GETPWNAM
   HashMap<string, string*> data;
 # endif
   time_t timestamp;
