@@ -1,66 +1,43 @@
 /*
-MyServer
-Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
-Foundation, Inc.
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
+  MyServer
+  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "myserver.h"
 #include <include/base/base64/mime_utils.h>
+#include <include/base/exceptions/checked.h>
 
-extern "C"
-{
 #ifndef WIN32
 # include <ctype.h>
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <string.h>
-}
 
 #include <include/base/string/stringutils.h>
 #include <include/base/string/securestr.h>
 
-#define strupos(x, y) (strustr (x, y) != NULL ? strustr (x, y) - x : -1)
-
-static char* strustr (char *source, char *s)
+static char* myserver_strupr (char * s)
 {
-
-  char *csource = new char[strlen (source) + 1];
-  if (csource == 0)
-    return 0;
-  char *cs = new char[strlen (s) + 1];
-  if (cs == 0)
-  {
-    delete [] csource;
-    return 0;
-  }
-  strncpy (csource, source, (strlen (source) + 2));
-  strncpy (cs, s, (strlen (s) + 2));
-  strupr (csource);
-  strupr (cs);
-  char *result = strstr (csource, cs);
-  if (result != NULL)
-  {
-    int pos =static_cast<int>(result - csource);
-    result = source;
-    result += pos;
-  }
-  delete [] csource;
-  delete [] cs;
-  return result;
+  unsigned int len = strlen (s);
+  for (register unsigned int i = 0; i < len; i++)
+    s[i] = toupper (s[i]);
+  return s;
 }
 
 const char base64chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
@@ -181,92 +158,6 @@ const char QpEncodeMap[] =
 
 
 
-char* CBase64Utils::mimeDecodeMailHeaderField (char *s)
-{
-
-  if (s == NULL) return s;
-  if (s[strlen (s) - 2] == '\r')
-  {
-    s[strlen (s) - 2] = '\0';
-  }
-  char *s1 = s;
-  char *rest = NULL;
-  char *start = NULL;
-  while (*s1 == ' ') s1++;
-  if (strupos (s1, (char*) "=?") > 0)
-  {
-    int startendpos =static_cast<int>(strupos (s1, (char*)"=?"));
-    start = new char[startendpos + 1];
-    strncpy (start, s, startendpos);
-    start[startendpos] = '\0';
-    s1 += startendpos;
-  }
-  if (strupos (s1, (char*) "=?") == 0)
-  {
-    int alloclen;
-    char *decodedText=0;
-    int plainpos =static_cast<int>(strupos (s1, (char*) "Q?="));
-    if (plainpos > 0)
-    {
-      plainpos += 3;
-      char *m = s1 + plainpos;
-      plainpos +=static_cast<int>(strupos (m, (char*)"?="));
-    }
-    else
-    {
-      plainpos = static_cast<int>(strupos (s1, (char*) "?="));
-    }
-    if (plainpos > 1)
-    {
-      char *mid = s1 + plainpos + 2;
-      s1[plainpos] = '\0';
-      if (strlen (mid) > 0)
-      {
-        rest = new char[strlen (mid) + 1];
-        strncpy (rest, mid,(strlen (mid) + 2));
-      }
-    }
-    if (strupos (s1, (char*) "?Q?") > 0)
-    {
-      CQPUtils qp;
-      int pos = static_cast<int>(strupos (s1, (char*) "?Q?"));
-      s1 += pos;
-      if (strlen (s1) < 4) return s;
-      s1 += 3;
-      decodedText = qp.decode (s1);
-    }
-    if (strupos (s1, (char*) "?B?") > 0)
-    {
-      CBase64Utils bu;
-      int sLen;
-      int pos = static_cast<int>(strupos (s1, (char*) "?B?"));
-      s1 += pos;
-      if (strlen (s1) < 4) return s;
-      s1 += 3;
-      sLen = static_cast<int>(strlen (s1));
-      decodedText = bu.decode (s1, &sLen);
-    }
-    alloclen =static_cast<int>(strlen (decodedText)) + 1;
-    if (start != NULL) alloclen +=static_cast<int>(strlen (start));
-    if (rest != NULL) alloclen +=static_cast<int>(strlen (rest));
-    alloclen *= sizeof (char);
-    s = (char*)realloc (s, alloclen);
-    s[0] = '\0';
-    if (start != NULL)
-    {
-      strncat (s, start, strlen (s));
-    }
-    strncat (s, decodedText, strlen (s));
-    if (rest != NULL)
-    {
-      strncat (s, rest, strlen (s));
-    }
-    delete [] decodedText;
-  }
-  return s;
-}
-
-
 CBase64Utils::CBase64Utils ()
 {
   ErrorCode = 0;
@@ -277,7 +168,7 @@ CBase64Utils::~CBase64Utils ()
 
 }
 /*!
- *Decode a string using the Base64 codification
+  Decode a string using the Base64 codification
  */
 char* CBase64Utils::encode (const char *input, int bufsize)
 {
@@ -388,7 +279,7 @@ char* CBase64Utils::encode (const char *input, int bufsize)
 }
 
 /*!
- *Decode a Base64 coded string.
+  Decode a Base64 coded string.
  */
 char* CBase64Utils::decode (const char *input, int *bufsize)
 {
@@ -528,8 +419,6 @@ char* CQPUtils::decode (char *input)
 
 #define BufAdd 10
 
-
-
 char* CQPUtils::expandBuffer (char *buffer, int UsedSize, int *BufSize,
                              int Singlechar)
 {
@@ -539,7 +428,7 @@ char* CQPUtils::expandBuffer (char *buffer, int UsedSize, int *BufSize,
   if (UsedSize >= *BufSize - AddVal)
   {
     *BufSize += BufAdd;
-    return (char*)realloc (buffer, *BufSize * sizeof (char));
+    return (char*) checked::realloc (buffer, *BufSize * sizeof (char));
   }
   return buffer;
 }
@@ -572,9 +461,9 @@ char* CQPUtils::encode (char *input)
       }
       finalresult = expandBuffer (finalresult, UsedSize, &BufSize, 0);
 
-      snprintf (mids, 3, "%X", mid);
+      gnulib::snprintf (mids, 3, "%X", mid);
 
-      strupr (mids);
+      myserver_strupr (mids);
       *(fresult++) = '=';
       *(fresult++) = mids[0];
       *(fresult++) = mids[1];
