@@ -27,36 +27,34 @@
 #include <include/conf/xml_conf.h>
 
 
-static VhostManagerHandler *builder (ListenThreads* lt, LogManager* lm)
+static VhostManagerHandler *builder (ListenThreads *lt, LogManager *lm)
 {
   return new XmlVhostHandler (lt, lm);
 }
 
 /*!
- * Register the builder on the vhost manager.
- *
- * \param manager Where register the builder.
+  Register the builder on the vhost manager.
+
+  \param manager Where register the builder.
  */
-void XmlVhostHandler::registerBuilder (VhostManager& manager)
+void XmlVhostHandler::registerBuilder (VhostManager &manager)
 {
   string xml ("xml");
   manager.registerBuilder (xml, builder);
 }
 
 /*!
- *XmlVhostHandler add function.
- *\param vh The virtual host to add.
+  XmlVhostHandler add function.
+  \param vh The virtual host to add.
  */
-int XmlVhostHandler::addVHost (Vhost* vh)
+int XmlVhostHandler::addVHost (Vhost *vh)
 {
-  list<Vhost*>::iterator it;
-
-  mutex.lock ();
+  vector<Vhost*>::iterator it;
 
   /* Be sure there is a listening thread on the specified port.  */
   listenThreads->addListeningThread (vh->getPort ());
 
-  it = hostList.begin ();
+  it = hosts.begin ();
 
   try
     {
@@ -74,120 +72,100 @@ int XmlVhostHandler::addVHost (Vhost* vh)
                                 _("The protocol \"%s\" is used but not loaded"),
                                     protocol.c_str ());
 
-      hostList.push_back (vh);
-      mutex.unlock ();
+      hosts.push_back (vh);
       return 0;
     }
   catch (...)
     {
-      mutex.unlock ();
       return -1;
     };
 }
 
 /*!
- *\see VhostManager#getVHost
+  \see VhostManager#getVHost
  */
-Vhost* XmlVhostHandler::getVHost (const char* host, const char* ip, u_short port)
+Vhost* XmlVhostHandler::getVHost (const char *host, const char *ip, u_short port)
 {
-  list<Vhost*>::iterator it;
-
-  mutex.lock ();
-
-  try
+  vector<Vhost*>::iterator it;
+  /*
+    Do a linear search here. We have to use the first full-matching
+    virtual host.
+  */
+  for (it = hosts.begin (); it != hosts.end (); it++)
     {
-      it = hostList.begin ();
+      Vhost* vh = *it;
 
-      /*Do a linear search here. We have to use the first full-matching
-       *virtual host.
-       */
-      for (; it != hostList.end (); it++)
-        {
-          Vhost* vh = *it;
-          /* Control if the host port is the correct one.  */
-          if (vh->getPort () != port)
-            continue;
-          /* If ip is defined check that it is allowed to connect to the host.  */
-          if (ip && !vh->isIPAllowed (ip))
-            continue;
-          /* If host is defined check if it is allowed to connect to the host.  */
-          if (host && !vh->isHostAllowed (host))
-            continue;
-          /* We find a valid host.  */
-          mutex.unlock ();
-          /* Add a reference.  */
-          vh->addRef ();
-          return vh;
-        }
-      mutex.unlock ();
-      return 0;
+      /* Control if the host port is the correct one.  */
+      if (vh->getPort () != port)
+        continue;
+
+      /* If ip is defined check that it is allowed to connect to the host.  */
+      if (ip && !vh->isIPAllowed (ip))
+        continue;
+
+      /* If host is defined check if it is allowed to connect to the host.  */
+      if (host && !vh->isHostAllowed (host))
+        continue;
+
+      /* Add a reference.  */
+      vh->addRef ();
+      return vh;
     }
-  catch (...)
-    {
-      mutex.unlock ();
-      return 0;
-    };
+  return 0;
+
+  return 0;
 }
 
 /*!
- *XmlVhostHandler costructor.
- *\param lt A ListenThreads object to use to create new threads.
- *\param lm The log manager to use.
+  XmlVhostHandler costructor.
+  \param lt A ListenThreads object to use to create new threads.
+  \param lm The log manager to use.
  */
-XmlVhostHandler::XmlVhostHandler (ListenThreads* lt, LogManager* lm)
+XmlVhostHandler::XmlVhostHandler (ListenThreads *lt, LogManager *lm)
 {
   listenThreads = lt;
-  hostList.clear ();
-  mutex.init ();
   logManager = lm;
 }
 
 /*!
- *Clean the virtual hosts.
+  Clean the virtual hosts.
  */
 void XmlVhostHandler::clean ()
 {
-  list<Vhost*>::iterator it;
-
-  mutex.lock ();
-
-  it = hostList.begin ();
+  vector<Vhost*>::iterator it;
 
+  it = hosts.begin ();
   try
     {
-      for (;it != hostList.end (); it++)
+      for (;it != hosts.end (); it++)
         delete *it;
 
-      hostList.clear ();
-
-      mutex.unlock ();
+      hosts.clear ();
     }
   catch (...)
     {
-      mutex.unlock ();
       return;
     };
 }
 
 /*!
- *vhostmanager destructor.
+  vhostmanager destructor.
  */
 XmlVhostHandler::~XmlVhostHandler ()
 {
   clean ();
-  mutex.destroy ();
 }
 
 /*!
- *Returns the entire virtual hosts list.
+  Returns the entire virtual hosts list.
  */
-list<Vhost*>* XmlVhostHandler::getVHostList ()
+vector<Vhost*>* XmlVhostHandler::getVHostList ()
 {
-  return &(this->hostList);
+  return &(this->hosts);
 }
 
 /*!
- *Change the file owner for the log locations.
+  Change the file owner for the log locations.
  */
 void XmlVhostHandler::changeLocationsOwner ()
 {
@@ -201,7 +179,7 @@ void XmlVhostHandler::changeLocationsOwner ()
        *Change the log files owner if a different user or group
        *identifier is specified.
        */
-      for (list<Vhost*>::iterator it = hostList.begin (); it != hostList.end (); it++)
+      for (vector<Vhost*>::iterator it = hosts.begin (); it != hosts.end (); it++)
         {
           int err;
           Vhost* vh = *it;
@@ -210,28 +188,28 @@ void XmlVhostHandler::changeLocationsOwner ()
           err = logManager->chown (vh, "ACCESSLOG", uid, gid);
           if (err)
             Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                    _("Error while changing accesses log locations owner"));
+                    _("Error while changing accesses log owner"));
 
           err = logManager->chown (vh, "WARNINGLOG", uid, gid);
           if (err)
             Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                    _("Error while changing log locations owner"));
+                    _("Error while changing warnings log owner"));
         }
     }
 }
 
 
 /*!
- *Returns the number of hosts in the list
+  Returns the number of hosts in the list
  */
 int XmlVhostHandler::getHostsNumber ()
 {
-  return hostList.size ();
+  return hosts.size ();
 }
 
 
 /*!
- *Load a log XML node.
+  Load a log XML node.
  */
 void
 XmlVhostHandler::loadXMLlogData (string name, Vhost* vh, xmlNode* lcur)
@@ -257,7 +235,7 @@ XmlVhostHandler::loadXMLlogData (string name, Vhost* vh, xmlNode* lcur)
   for (; stream; stream = stream->next, location.assign (""), cycle = 0, filters.clear ())
     {
       if (stream->type == XML_ELEMENT_NODE &&
-          !xmlStrcmp (stream->name, (xmlChar const*)"STREAM"))
+          !xmlStrcmp (stream->name, (xmlChar const*) "STREAM"))
         {
           xmlAttr* streamAttr = stream->properties;
           while (streamAttr)
@@ -276,7 +254,7 @@ XmlVhostHandler::loadXMLlogData (string name, Vhost* vh, xmlNode* lcur)
           for (; filterList; filterList = filterList->next)
             {
               if (filterList->type == XML_ELEMENT_NODE &&
-                  !xmlStrcmp (filterList->name, (xmlChar const*)"FILTER"))
+                  !xmlStrcmp (filterList->name, (xmlChar const*) "FILTER"))
                 {
                   if (filterList->children && filterList->children->content)
                     {
@@ -312,9 +290,9 @@ XmlVhostHandler::loadXMLlogData (string name, Vhost* vh, xmlNode* lcur)
 }
 
 /*!
- *Load the virtual hosts from a XML configuration file
- *Returns non-null on errors.
- *\param filename The XML file to open.
+  Load the virtual hosts from a XML configuration file
+  Returns non-null on errors.
+  \param filename The XML file to open.
  */
 int XmlVhostHandler::load (const char *filename)
 {
@@ -334,7 +312,7 @@ int XmlVhostHandler::load (const char *filename)
     {
       xmlNodePtr lcur;
       Vhost *vh;
-      if (xmlStrcmp (node->name, (const xmlChar *)"VHOST"))
+      if (xmlStrcmp (node->name, (const xmlChar *) "VHOST"))
         continue;
       lcur = node->children;
       vh = new Vhost (logManager);
@@ -354,38 +332,31 @@ int XmlVhostHandler::load (const char *filename)
           XmlConf::build (lcur, vh->getHashedDataTrees (),
                           vh->getHashedData ());
 
-          if (!lcur->children || !lcur->children->content)
-            {
-              lcur = lcur->next;
-              continue;
-            }
-
-          if (!xmlStrcmp (lcur->name, (const xmlChar *)"HOST"))
+          if (!xmlStrcmp (lcur->name, (const xmlChar *) "HOST"))
             {
               int useRegex = 0;
               for (xmlAttr *attrs = lcur->properties; attrs; attrs = attrs->next)
                 {
-                  if (!xmlStrcmp (attrs->name, (const xmlChar *)"isRegex")
+                  if (!xmlStrcmp (attrs->name, (const xmlChar *) "isRegex")
                       && attrs->children && attrs->children->content
                       && (!xmlStrcmp (attrs->children->content,
-                                     (const xmlChar *)"YES")))
+                                     (const xmlChar *) "YES")))
                         useRegex = 1;
                 }
 
               vh->addHost ((const char*)lcur->children->content, useRegex);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"NAME"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "NAME"))
             {
               vh->setName ((char*)lcur->children->content);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"LOCATION"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "LOCATION"))
             {
-              string loc (vh->getDocumentRoot ());
-              loc.append ("/");
+              string loc;
 
               for (xmlAttr *attrs = lcur->properties; attrs; attrs = attrs->next)
-                if (!xmlStrcmp (attrs->name, (const xmlChar *)"path"))
-                  loc.append ((const char*) attrs->children->content);
+                if (!xmlStrcmp (attrs->name, (const xmlChar *) "path"))
+                  loc = ((const char*) attrs->children->content);
 
               MimeRecord *record = XmlMimeHandler::readRecord (lcur);
               MimeRecord *prev = vh->addLocationMime (loc, record);
@@ -400,35 +371,35 @@ int XmlVhostHandler::load (const char *filename)
 
               vh->getLocationsMime ()->put (loc, record);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"SSL_PRIVATEKEY"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_PRIVATEKEY"))
             {
               string pk ((char*)lcur->children->content);
               sslContext->setPrivateKeyFile (pk);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"SSL_CERTIFICATE"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_CERTIFICATE"))
             {
               string certificate ((char*)lcur->children->content);
               sslContext->setCertificateFile (certificate);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"CONNECTIONS_PRIORITY"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "CONNECTIONS_PRIORITY"))
             {
               vh->setDefaultPriority (atoi ((const char*)lcur->children->content));
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"SSL_PASSWORD"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_PASSWORD"))
             {
               string pw ((char*)lcur->children->content);
               sslContext->setPassword (pw);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"IP"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "IP"))
             {
               int useRegex = 0;
               xmlAttr *attrs = lcur->properties;
 
               while (attrs)
                 {
-                  if (!xmlStrcmp (attrs->name, (const xmlChar *)"isRegex")
+                  if (!xmlStrcmp (attrs->name, (const xmlChar *) "isRegex")
                       && !xmlStrcmp (attrs->children->content,
-                                     (const xmlChar *)"YES"))
+                                     (const xmlChar *) "YES"))
                     useRegex = 1;
 
                   attrs = attrs->next;
@@ -436,7 +407,7 @@ int XmlVhostHandler::load (const char *filename)
 
               vh->addIP ((char*)lcur->children->content, useRegex);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"PORT"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "PORT"))
             {
               int val = atoi ((char*)lcur->children->content);
               if (val > (1 << 16) || val <= 0)
@@ -444,7 +415,7 @@ int XmlVhostHandler::load (const char *filename)
                       _("Specified invalid port %s"), lcur->children->content);
               vh->setPort ((u_short)val);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"PROTOCOL"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "PROTOCOL"))
             {
               char* lastChar = (char*)lcur->children->content;
               while (*lastChar != '\0')
@@ -454,7 +425,7 @@ int XmlVhostHandler::load (const char *filename)
                 }
               vh->setProtocolName ((char*)lcur->children->content);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"DOCROOT"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "DOCROOT"))
             {
               char* lastChar = (char*)lcur->children->content;
               while (*(lastChar+1) != '\0')
@@ -465,7 +436,7 @@ int XmlVhostHandler::load (const char *filename)
 
               vh->setDocumentRoot ((const char*)lcur->children->content);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"SYSROOT"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SYSROOT"))
             {
               char* lastChar = (char*)lcur->children->content;
 
@@ -477,25 +448,25 @@ int XmlVhostHandler::load (const char *filename)
 
               vh->setSystemRoot ((const char*)lcur->children->content);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"ACCESSLOG"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "ACCESSLOG"))
             {
               loadXMLlogData ("ACCESSLOG", vh, lcur);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"WARNINGLOG"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "WARNINGLOG"))
             {
               loadXMLlogData ("WARNINGLOG", vh, lcur);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"MIME_FILE"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "MIME_FILE"))
             {
               string hnd ("xml");
               for (xmlAttr *attrs = lcur->properties; attrs; attrs = attrs->next)
                 {
-                  if (!xmlStrcmp (attrs->name, (const xmlChar *)"name")
+                  if (!xmlStrcmp (attrs->name, (const xmlChar *) "name")
                       && attrs->children && attrs->children->content)
                     hnd.assign((const char*) attrs->children->content);
                 }
 
-              const char *filename = (const char*)lcur->children->content;
+              const char *filename = (const char*) lcur->children->content;
               MimeManagerHandler *handler =
                 Server::getInstance ()->getMimeManager ()->buildHandler (hnd);
 
@@ -514,7 +485,7 @@ int XmlVhostHandler::load (const char *filename)
                 }
               vh->setMimeHandler (handler);
             }
-          else if (!xmlStrcmp (lcur->name, (const xmlChar *)"THROTTLING_RATE"))
+          else if (!xmlStrcmp (lcur->name, (const xmlChar *) "THROTTLING_RATE"))
             {
               u_long rate = (u_long)atoi ((char*)lcur->children->content);
               vh->setThrottlingRate (rate);
@@ -559,62 +530,24 @@ int XmlVhostHandler::load (const char *filename)
 }
 
 /*!
- *\see VhostManager#getVHostByNumber
+  \see VhostManager#getVHost
  */
-Vhost* XmlVhostHandler::getVHostByNumber (int n)
+Vhost* XmlVhostHandler::getVHost (u_long n)
 {
-  Vhost* ret = 0;
-  mutex.lock ();
-  try
-    {
-      list<Vhost*>::iterator i = hostList.begin ();
-      for ( ; i != hostList.end (); i++)
-        {
-          if (!(n--))
-            {
-              ret = *i;
-              ret->addRef ();
-              break;
-            }
-        }
-      mutex.unlock ();
+  if (n > hosts.size ())
+    return NULL;
 
-      return ret;
-    }
-  catch (...)
-    {
-      mutex.unlock ();
-      return ret;
-    };
+  return hosts.at (n - 1);
 }
 
 /*!
- *Remove a virtual host by its position in the list
- *First position is zero.
- *\param n The virtual host identifier in the list.
+  Remove a virtual host by its position in the list
+  First position is zero.
+  \param n The virtual host identifier in the list.
  */
-int XmlVhostHandler::removeVHost (int n)
+int XmlVhostHandler::removeVHost (u_long n)
 {
-  mutex.lock ();
-  try
-    {
-      list<Vhost*>::iterator i = hostList.begin ();
-
-      for ( ;i != hostList.end (); i++)
-        {
-          if (!(n--))
-            {
-              delete *i;
-              mutex.unlock ();
-              return 1;
-            }
-        }
-      mutex.unlock ();
-      return 0;
-    }
-  catch (...)
-    {
-      mutex.unlock ();
-      return 0;
-    };
+  vector<Vhost*>::iterator it = hosts.erase (hosts.begin () + n - 1);
+  delete *it;
+  return 0;
 }
