@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +16,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 
 #include <include/filter/stream.h>
 
@@ -24,17 +25,17 @@
 using namespace std;
 
 /*!
- *Read [len] characters from the stream. Returns -1 on errors.
+  Read [len] characters from the stream. Returns -1 on errors.
  */
-int Stream::read (char* buffer,u_long len, u_long *nbr)
+int Stream::read (char* buffer,size_t len, size_t *nbr)
 {
   *nbr = 0;
   return 0;
 }
 
 /*!
- *Close the stream.
- *\return -1 on errors.
+  Close the stream.
+  \return -1 on errors.
  */
 int Stream::close ()
 {
@@ -42,18 +43,18 @@ int Stream::close ()
 }
 
 /*!
- *Write [len] characters to the stream. Returns -1 on errors.
+  Write [len] characters to the stream. Returns -1 on errors.
  */
-int Stream::write (const char* buffer, u_long len, u_long *nbw)
+int Stream::write (const char* buffer, size_t len, size_t *nbw)
 {
   *nbw = 0;
   return 0;
 }
 
 /*!
- *Write remaining data to the stream.
+  Write remaining data to the stream.
  */
-int Stream::flush (u_long* nbw)
+int Stream::flush (size_t* nbw)
 {
   *nbw = 0;
   return 0;
@@ -70,7 +71,7 @@ Stream::~Stream ()
 }
 
 /*!
- *Get the file handle.
+  Get the file handle.
  */
 Handle Stream::getHandle ()
 {
