@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -15,13 +16,13 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 #include <include/protocol/protocol.h>
 #include <include/server/clients_thread.h>
 #include <include/server/server.h>
 
 /*!
- * Load the protocol. Called once at runtime.
+  Load the protocol. Called once at runtime.
  */
 int Protocol::loadProtocol ()
 {
@@ -29,7 +30,7 @@ int Protocol::loadProtocol ()
 }
 
 /*!
- * Unload the protocol. Called once.
+  Unload the protocol. Called once.
  */
 int Protocol::unLoadProtocol ()
 {
@@ -37,8 +38,8 @@ int Protocol::unLoadProtocol ()
 }
 
 /*!
- * Returns the name of the protocol. If an out buffer is
- * defined fullfill it with the name too.
+  Returns the name of the protocol. If an out buffer is
+  defined fullfill it with the name too.
  */
 const char* Protocol::getName ()
 {
@@ -46,7 +47,7 @@ const char* Protocol::getName ()
 }
 
 /*!
- * Constructor for the class protocol.
+  Constructor for the class protocol.
  */
 Protocol::Protocol ()
 {
@@ -55,7 +56,7 @@ Protocol::Protocol ()
 }
 
 /*!
- * Destroy the object.
+  Destroy the object.
  */
 Protocol::~Protocol ()
 {
