@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2007, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2007, 2009, 2010 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -15,12 +16,12 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 
 #include <include/protocol/protocol_buffer.h>
 
 /*!
- *Create the buffer.
+  Create the buffer.
  */
 ProtocolBuffer::ProtocolBuffer ()
 {
@@ -28,7 +29,7 @@ ProtocolBuffer::ProtocolBuffer ()
 }
 
 /*!
- *Destroy the protocol buffer object.
+  Destroy the protocol buffer object.
  */
 ProtocolBuffer::~ProtocolBuffer ()
 {
@@ -36,9 +37,9 @@ ProtocolBuffer::~ProtocolBuffer ()
 }
 
 /*!
- *Check if the protocol allows the connection to be removed.
- *\param wait Define if the protocol can wait that the current job is
- *finished before.
+  Check if the protocol allows the connection to be removed.
+  \param wait Define if the protocol can wait that the current job is
+  finished before.
  */
 bool ProtocolBuffer::allowDelete (bool wait)
 {
