@@ -1,19 +1,19 @@
 /*
- MyServer
- Copyright (C) 2008, 2009, 2010 Free Software Foundation, Inc.
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 3 of the License, or
- (at your option) any later version.
+  MyServer
+  Copyright (C) 2008, 2009, 2010 Free Software Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 #include "myserver.h"
 #include <ctype.h>
@@ -42,7 +42,9 @@ class TestHttpRequest : public CppUnit::TestFixture
   CPPUNIT_TEST (testIncompleteHeader);
   CPPUNIT_TEST (testDefaultHttpRequest);
   CPPUNIT_TEST (testValidRequest);
+  CPPUNIT_TEST (testKeepAlive);
   CPPUNIT_TEST (testResetHttpRequest);
+  CPPUNIT_TEST (testClearValue);
   CPPUNIT_TEST_SUITE_END ();
 
 public:
@@ -56,6 +58,50 @@ public:
 
   }
 
+
+  void testKeepAlive ()
+  {
+    HttpRequestHeader header;
+    Connection connection;
+    u_long requestLength;
+    const char * requestStr;
+    int ret;
+#define BUILD_KEEPALIVE_REQ(X) "GET / HTTP/1.1\r\n" \
+      "Connection: " X "\r\n"                       \
+      "Host: localhost\r\n\r\n"
+
+    requestStr = BUILD_KEEPALIVE_REQ ("Keep-Alive");
+    ret = HttpHeaders::buildHTTPRequestHeaderStruct (requestStr,
+                                                     strlen (requestStr),
+                                                     &requestLength,
+                                                     &header,
+                                                     &connection);
+
+    CPPUNIT_ASSERT (header.isKeepAlive ());
+
+    requestStr = BUILD_KEEPALIVE_REQ ("close");
+    HttpHeaders::resetHTTPRequest (&header);
+    ret = HttpHeaders::buildHTTPRequestHeaderStruct (requestStr,
+                                                     strlen (requestStr),
+                                                     &requestLength,
+                                                     &header,
+                                                     &connection);
+
+    CPPUNIT_ASSERT (! header.isKeepAlive ());
+
+    requestStr = BUILD_KEEPALIVE_REQ ("keep-Alive");
+    HttpHeaders::resetHTTPRequest (&header);
+    ret = HttpHeaders::buildHTTPRequestHeaderStruct (requestStr,
+                                                     strlen (requestStr),
+                                                     &requestLength,
+                                                     &header,
+                                                     &connection);
+
+    CPPUNIT_ASSERT (header.isKeepAlive ());
+
+#undef BUILD_KEEPALIVE_REQ
+  }
+
   void testSimpleHeader ()
   {
 
@@ -75,6 +121,8 @@ public:
     CPPUNIT_ASSERT (header.ver.compare ("HTTP/1.1") == 0);
     CPPUNIT_ASSERT (header.uri.compare ("/resource") == 0);
     CPPUNIT_ASSERT (header.uriOpts.compare ("args") == 0);
+
+    CPPUNIT_ASSERT (header.getValue ("Host", 0));
     CPPUNIT_ASSERT (header.getValue ("Host", 0)->compare ("localhost") == 0);
   }
 
@@ -178,12 +226,12 @@ public:
     CPPUNIT_ASSERT (!strcmp (header.digestNonce,
                              "88b29c4b136e2efee059647dbac10427"));
     CPPUNIT_ASSERT (!strcmp (header.digestUri, "/res/"));
-    CPPUNIT_ASSERT (!strcmp (header.digestUsername, "user")); 
-    CPPUNIT_ASSERT (!strcmp (header.digestNc, "00000001")); 
-    CPPUNIT_ASSERT (!strcmp (header.digestQop, "auth")); 
+    CPPUNIT_ASSERT (!strcmp (header.digestUsername, "user"));
+    CPPUNIT_ASSERT (!strcmp (header.digestNc, "00000001"));
+    CPPUNIT_ASSERT (!strcmp (header.digestQop, "auth"));
     CPPUNIT_ASSERT (!strcmp (header.digestResponse,
-                             "e979c020b57cc0e86e46d5c8cad8497e")); 
-    CPPUNIT_ASSERT (!strcmp (header.digestCnonce, "c40dc807904a2357")); 
+                             "e979c020b57cc0e86e46d5c8cad8497e"));
+    CPPUNIT_ASSERT (!strcmp (header.digestCnonce, "c40dc807904a2357"));
 
   }
 
@@ -206,6 +254,9 @@ public:
                                                     &requestLength,
                                                     &header,
                                                     &connection);
+
+    CPPUNIT_ASSERT_EQUAL (strcmp ("user", connection.getLogin ()), 0);
+    CPPUNIT_ASSERT_EQUAL (strcmp ("freedom", connection.getPassword ()), 0);
     CPPUNIT_ASSERT (ret == 200);
   }
 
@@ -220,7 +271,7 @@ public:
     CPPUNIT_ASSERT (header.uriOpts.compare ("") == 0);
     CPPUNIT_ASSERT (header.ver.compare ("HTTP/1.1") == 0);
     CPPUNIT_ASSERT (header.uriOptsPtr == NULL);
-    CPPUNIT_ASSERT (header.getValue ("NotExists", 0) == NULL);
+    CPPUNIT_ASSERT (header.getValue ("NotExists", NULL) == NULL);
   }
 
 
@@ -234,9 +285,20 @@ public:
     CPPUNIT_ASSERT (header.uriOpts.compare ("") == 0);
     CPPUNIT_ASSERT (header.ver.compare ("") == 0);
     CPPUNIT_ASSERT (header.uriOptsPtr == NULL);
-    CPPUNIT_ASSERT (header.getValue ("NotExists", 0) == NULL);
+    CPPUNIT_ASSERT (header.getValue ("NotExists", NULL) == NULL);
   }
 
+  void testClearValue ()
+  {
+    HttpRequestHeader header;
+    CPPUNIT_ASSERT (header.getValue ("Foo", NULL) == NULL);
+    header.setValue ("Foo", "Bar");
+    CPPUNIT_ASSERT (header.getValue ("Foo", NULL));
+    header.clearValue ("Foo");
+    CPPUNIT_ASSERT (header.getValue ("Foo", NULL) == NULL);
+
+
+  }
 };
 
 
