@@ -32,6 +32,7 @@
 #include <include/log/log_manager.h>
 #include <include/filter/filters_factory.h>
 #include <include/base/file/files_utility.h>
+#include <include/base/socket/socket.h>
 #include <include/base/file/file.h>
 #include <include/base/utility.h>
 #include <include/filter/gzip/gzip.h>
@@ -93,6 +94,21 @@ public:
     lm = new LogManager (ff);
   }
 
+  void tearDown ()
+  {
+    lm->close (this, "test", "file://foo");
+    delete lm;
+    delete ff;
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
+  }
+
+
   void testEmpty ()
   {
     CPPUNIT_ASSERT (lm->empty ());
@@ -149,9 +165,14 @@ public:
     list<string> filters;
     File f;
     char buf[message.size () + 1];
-    u_long nbr;
-    FilesUtility::deleteFile ("foo");
-
+    size_t nbr;
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
     lm->add (this, "test", "file://foo", filters, 0);
     lm->log (this, "test", "file://foo", message);
     lm->close (this);
@@ -166,7 +187,13 @@ public:
   void testFileStreamClose ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
 
@@ -176,7 +203,13 @@ public:
   void testCloseAnAlreadyClosedFileStream ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->close (this, "test", "file://foo");
@@ -193,11 +226,17 @@ public:
     list<string> filters;
     File f;
     char buf[64];
-    u_long nbr;
-    LogStream* ls;
+    size_t nbr;
+    LogStream* ls = NULL;
     list<string> cs;
     list<string>::iterator it;
-    FilesUtility::deleteFile ("foobar");
+    try
+      {
+        FilesUtility::deleteFile ("foobar");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foobar", filters, 10);
     lm->log (this, "test", "file://foobar", message);
@@ -211,6 +250,7 @@ public:
     gotMessage1.assign (buf);
 
     lm->get (this, "test", "file://foobar", &ls);
+    CPPUNIT_ASSERT (ls);
     cs = ls->getCycledStreams ();
     for (it = cs.begin (); it != cs.end (); it++)
       {
@@ -219,11 +259,24 @@ public:
         buf[nbr] = '\0';
         f.close ();
         gotMessage.assign (buf);
-        FilesUtility::deleteFile (*it);
+        try
+          {
+            FilesUtility::deleteFile (*it);
+          }
+        catch (...)
+          {
+          }
       }
 
     lm->close (this);
-    FilesUtility::deleteFile ("foobar");
+
+    try
+      {
+        FilesUtility::deleteFile ("foobar");
+      }
+    catch (...)
+      {
+      }
 
     CPPUNIT_ASSERT (!message1.compare (gotMessage1));
     CPPUNIT_ASSERT (!message.compare (gotMessage));
@@ -243,7 +296,14 @@ public:
   void testMessageLevelLessThanLogManagerOne ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->setLevel (MYSERVER_LOG_MSG_WARNING);
@@ -255,7 +315,14 @@ public:
   void testMessageLevelEqualToLogManagerOne ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->setLevel (MYSERVER_LOG_MSG_WARNING);
@@ -267,7 +334,14 @@ public:
   void testClear ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->add (this, "test", "console://stdout", filters, 0);
@@ -284,10 +358,16 @@ public:
     File f;
     char gzipChainComp[64];
     char gzipChainDecomp[64];
-    u_long nbr;
+    size_t nbr;
     GzipDecompress gzdc;
 
-    FilesUtility::deleteFile ("fooz");
+    try
+      {
+        FilesUtility::deleteFile ("fooz");
+      }
+    catch (...)
+      {
+      }
 
     filters.push_back ("gzip");
     lm->add (this, "test", "file://fooz", filters, 0);
@@ -301,7 +381,13 @@ public:
                      gzipChainDecomp, 64);
     gzipChainDecomp[message.size ()] = '\0';
 
-    FilesUtility::deleteFile ("fooz");
+    try
+      {
+        FilesUtility::deleteFile ("fooz");
+      }
+    catch (...)
+      {
+      }
 
     CPPUNIT_ASSERT (!message.compare (gzipChainDecomp));
   }
@@ -318,11 +404,18 @@ public:
     char gzipComp[128];
     char gzipDecomp[128];
     GzipDecompress gzdc;
-    u_long nbr = 0;
+    size_t nbr = 0;
     list<string> cs;
     list<string>::iterator it;
-    LogStream* ls;
-    FilesUtility::deleteFile ("fooc");
+    LogStream* ls = NULL;
+
+    try
+      {
+        FilesUtility::deleteFile ("fooc");
+      }
+    catch (...)
+      {
+      }
 
     filters.push_back ("gzip");
     lm->add (this, "test", "file://fooc", filters, cycleLog);
@@ -337,6 +430,7 @@ public:
     gzipDecomp[message1.size ()] = '\0';
     gotMessage1.assign (gzipDecomp);
     lm->get (this, "test", "file://fooc", &ls);
+    CPPUNIT_ASSERT (ls);
     cs = ls->getCycledStreams ();
     for (it = cs.begin (); it != cs.end (); it++)
       {
@@ -348,10 +442,24 @@ public:
                          gzipDecomp, 128);
         gzipDecomp[message.size ()] = '\0';
         gotMessage.assign (gzipDecomp);
-        FilesUtility::deleteFile (*it);
+
+        try
+          {
+            FilesUtility::deleteFile (*it);
+          }
+        catch (...)
+          {
+          }
       }
     lm->close (this);
-    FilesUtility::deleteFile ("fooc");
+
+    try
+      {
+        FilesUtility::deleteFile ("fooc");
+      }
+    catch (...)
+      {
+      }
 
     CPPUNIT_ASSERT (!message1.compare (gotMessage1));
     CPPUNIT_ASSERT (!message.compare (gotMessage));
@@ -360,7 +468,14 @@ public:
   void testCountSingleLogStream ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "console://stdout", filters, 0);
     lm->add (this, "test_1", "console://stderr", filters, 0);
@@ -372,7 +487,14 @@ public:
   void testCountSameTypeLogStreams ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "console://stdout", filters, 0);
     lm->add (this, "test_1", "console://stderr", filters, 0);
@@ -384,7 +506,14 @@ public:
   void testCountAllLogStreamsOwnedByAnObject ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "console://stdout", filters, 0);
     lm->add (this, "test_1", "console://stderr", filters, 0);
@@ -405,7 +534,14 @@ public:
     list<string> filters;
     list<string> tmp;
     list<string> l;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->add (this, "test", "console://stdout", filters, 0);
@@ -425,7 +561,14 @@ public:
     list<string> filters;
     list<string> tmp;
     list<string> l;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->add (this, "test", "console://stdout", filters, 0);
@@ -443,7 +586,14 @@ public:
   {
     list<string> filters;
     LogStream* ls;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
 
@@ -454,7 +604,14 @@ public:
   {
     list<string> filters;
     LogStream* ls;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
 
@@ -468,10 +625,16 @@ public:
     string message1;
     string message2;
     char buf[128];
-    u_long nbr;
+    size_t nbr;
     ostringstream oss;
 
-    FilesUtility::deleteFile ("fooa");
+    try
+      {
+        FilesUtility::deleteFile ("fooa");
+      }
+    catch (...)
+      {
+      }
 
     oss << "message1" << endl;
     message1.assign (oss.str ());
@@ -489,7 +652,13 @@ public:
     f.close ();
     buf[nbr] = '\0';
 
-    FilesUtility::deleteFile ("fooa");
+    try
+      {
+        FilesUtility::deleteFile ("fooa");
+      }
+    catch (...)
+      {
+      }
 
     CPPUNIT_ASSERT (!string (buf).compare (message1.append (message2)));
   }
@@ -497,7 +666,14 @@ public:
   void testFileStreamAddWithNotExistingFilter ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
+
     filters.push_back ("not_existing_filter");
 
     CPPUNIT_ASSERT (lm->add (this, "test", "file://foo", filters, 0));
@@ -509,7 +685,8 @@ public:
 
     filters.push_back ("not_existing_filter");
 
-    CPPUNIT_ASSERT (lm->add (this, "test", "socket://127.0.0.1:6666", filters, 0));
+    CPPUNIT_ASSERT (lm->add (this, "test", "socket://" LOCALHOST_ADDRESS ":6666",
+                             filters, 0));
   }
 
   void testConsoleStreamAddWithNotExistingFilter ()
@@ -531,7 +708,14 @@ public:
   void testAddMultipleTimesTheSameKey ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
 
@@ -542,20 +726,34 @@ public:
   {
     list<string> filters;
     AnObject anObject;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
 
-    CPPUNIT_ASSERT (!lm->add (&anObject, "test", "file://foo", filters, 0));
+    CPPUNIT_ASSERT (!lm->add (&anObject, "test", "file://foo", filters, 0, 1));
   }
 
   void testAddLogStreamSharedByTheSameObject ()
   {
     list<string> filters;
+    try
+      {
     FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
+
     lm->add (this, "test", "file://foo", filters, 0);
 
-    CPPUNIT_ASSERT (!lm->add (this, "test1", "file://foo", filters, 0));
+    CPPUNIT_ASSERT (! lm->add (this, "test1", "file://foo", filters, 0, 1));
   }
 
   void testGetLogStreamSharedByDistinctObjects ()
@@ -565,10 +763,17 @@ public:
     list<const void*> l;
     LogStream* ls;
     LogStream* ls1;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
-    lm->add (&anObject, "test", "file://foo", filters, 0);
+    lm->add (&anObject, "test", "file://foo", filters, 0, 1);
     lm->getOwnersList ("file://foo", &l);
     lm->get (this, "test", "file://foo", &ls);
     lm->get (&anObject, "test", "file://foo", &ls1);
@@ -582,10 +787,17 @@ public:
     list<const void*> l;
     LogStream* ls;
     LogStream* ls1;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
-    lm->add (this, "test1", "file://foo", filters, 0);
+    lm->add (this, "test1", "file://foo", filters, 0, 1);
     lm->getOwnersList ("file://foo", &l);
     lm->get (this, "test", "file://foo", &ls);
     lm->get (this, "test1", "file://foo", &ls1);
@@ -599,11 +811,18 @@ public:
     AnObject anObject;
     AnObject anotherObject;
     list<const void*> l;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
-    lm->add (&anObject, "test1", "file://foo", filters, 0);
-    lm->add (&anotherObject, "test2", "file://foo", filters, 0);
+    lm->add (&anObject, "test1", "file://foo", filters, 0, 1);
+    lm->add (&anotherObject, "test2", "file://foo", filters, 0, 1);
     lm->remove (this);
     lm->remove (&anObject);
 
@@ -630,7 +849,14 @@ public:
   void testLogOnAClosedLogStream ()
   {
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
 
     lm->add (this, "test", "file://foo", filters, 0);
     lm->close (this, "test", "file://foo");
@@ -642,7 +868,15 @@ public:
   {
 #ifndef WIN32
     list<string> filters;
-    FilesUtility::deleteFile ("foo");
+
+    try
+      {
+        FilesUtility::deleteFile ("foo");
+      }
+    catch (...)
+      {
+      }
+
 
     lm->add (this, "test", "file://foo", filters, 0);
     ostringstream uidOss;
@@ -657,14 +891,6 @@ public:
 #endif
   }
 
-  void tearDown ()
-  {
-    lm->close (this, "test", "file://foo");
-    delete lm;
-    delete ff;
-    FilesUtility::deleteFile ("foo");
-  }
-
 private:
   LogManager* lm;
   FiltersFactory* ff;
